Package: distantia
Type: Package
Title: Advanced Toolset for Efficient Time Series Dissimilarity
        Analysis
Version: 2.0.3
Authors@R: 
    person(given = "Blas M.", 
          family = "Benito", , 
          email = "blasbenito@gmail.com", 
          role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-5105-7232"))
URL: https://blasbenito.github.io/distantia/
BugReports: https://github.com/BlasBenito/distantia/issues
Description: Fast C++ implementation of Dynamic Time Warping for time series dissimilarity analysis, with applications in environmental monitoring and sensor data analysis, climate science, signal processing and pattern recognition, and financial data analysis. Built upon the ideas presented in Benito and Birks (2020) <doi:10.1111/ecog.04895>, provides tools for analyzing time series of varying lengths and structures, including irregular multivariate time series. Key features include individual variable contribution analysis, restricted permutation tests for statistical significance, and imputation of missing data via GAMs. Additionally, the package provides an ample set of tools to prepare and manage time series data.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.1), doFuture
Imports: Rcpp, zoo, foreach, future.apply, lubridate, progressr
Suggests: roxyglobals, spelling, sf, lwgeom, testthat (>= 3.0.0)
Config/roxyglobals/filename: globals.R
Config/roxyglobals/unique: FALSE
Config/testthat/edition: 3
LinkingTo: Rcpp
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-13 13:16:25 UTC; blas
Author: Blas M. Benito [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-5105-7232>)
Maintainer: Blas M. Benito <blasbenito@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-13 13:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-13 14:44:55 UTC; unix
Archs: distantia.so.dSYM
