# Generated by roxygen2: do not edit by hand

export(auto_distance_cpp)
export(auto_sum_cpp)
export(auto_sum_full_cpp)
export(auto_sum_path_cpp)
export(color_continuous)
export(color_discrete)
export(cost_matrix_diagonal_cpp)
export(cost_matrix_diagonal_weighted_cpp)
export(cost_matrix_orthogonal_cpp)
export(cost_path_cpp)
export(cost_path_diagonal_bandwidth_cpp)
export(cost_path_diagonal_cpp)
export(cost_path_orthogonal_bandwidth_cpp)
export(cost_path_orthogonal_cpp)
export(cost_path_slotting_cpp)
export(cost_path_sum_cpp)
export(cost_path_trim_cpp)
export(distance)
export(distance_bray_curtis_cpp)
export(distance_canberra_cpp)
export(distance_chebyshev_cpp)
export(distance_chi_cpp)
export(distance_cosine_cpp)
export(distance_euclidean_cpp)
export(distance_hamming_cpp)
export(distance_hellinger_cpp)
export(distance_jaccard_cpp)
export(distance_ls_cpp)
export(distance_manhattan_cpp)
export(distance_matrix)
export(distance_matrix_cpp)
export(distance_russelrao_cpp)
export(distance_sorensen_cpp)
export(distantia)
export(distantia_aggregate)
export(distantia_boxplot)
export(distantia_cluster_hclust)
export(distantia_cluster_kmeans)
export(distantia_dtw)
export(distantia_dtw_plot)
export(distantia_ls)
export(distantia_matrix)
export(distantia_model_frame)
export(distantia_spatial)
export(distantia_stats)
export(distantia_time_delay)
export(f_binary)
export(f_clr)
export(f_detrend_difference)
export(f_detrend_linear)
export(f_detrend_poly)
export(f_hellinger)
export(f_list)
export(f_log)
export(f_percent)
export(f_proportion)
export(f_proportion_sqrt)
export(f_rescale_global)
export(f_rescale_local)
export(f_scale_global)
export(f_scale_local)
export(f_trend_linear)
export(f_trend_poly)
export(importance_dtw_cpp)
export(importance_dtw_legacy_cpp)
export(importance_ls_cpp)
export(momentum)
export(momentum_aggregate)
export(momentum_boxplot)
export(momentum_dtw)
export(momentum_ls)
export(momentum_model_frame)
export(momentum_spatial)
export(momentum_stats)
export(momentum_to_wide)
export(permute_free_by_row_cpp)
export(permute_free_cpp)
export(permute_restricted_by_row_cpp)
export(permute_restricted_cpp)
export(psi_auto_distance)
export(psi_auto_sum)
export(psi_cost_matrix)
export(psi_cost_path)
export(psi_cost_path_sum)
export(psi_distance_lock_step)
export(psi_distance_matrix)
export(psi_dtw_cpp)
export(psi_equation)
export(psi_equation_cpp)
export(psi_ls_cpp)
export(psi_null_dtw_cpp)
export(psi_null_ls_cpp)
export(subset_matrix_by_rows_cpp)
export(tsl_Inf_to_NA)
export(tsl_NaN_to_NA)
export(tsl_aggregate)
export(tsl_burst)
export(tsl_colnames_clean)
export(tsl_colnames_get)
export(tsl_colnames_prefix)
export(tsl_colnames_set)
export(tsl_colnames_suffix)
export(tsl_count_NA)
export(tsl_diagnose)
export(tsl_handle_NA)
export(tsl_init)
export(tsl_initialize)
export(tsl_join)
export(tsl_names_clean)
export(tsl_names_get)
export(tsl_names_set)
export(tsl_names_test)
export(tsl_ncol)
export(tsl_nrow)
export(tsl_plot)
export(tsl_repair)
export(tsl_resample)
export(tsl_simulate)
export(tsl_smooth)
export(tsl_stats)
export(tsl_subset)
export(tsl_time)
export(tsl_time_summary)
export(tsl_to_df)
export(tsl_transform)
export(utils_as_time)
export(utils_block_size)
export(utils_boxplot_common)
export(utils_check_args_distantia)
export(utils_check_args_matrix)
export(utils_check_args_momentum)
export(utils_check_args_path)
export(utils_check_args_tsl)
export(utils_check_args_zoo)
export(utils_check_distance_args)
export(utils_check_list_class)
export(utils_clean_names)
export(utils_cluster_hclust_optimizer)
export(utils_cluster_kmeans_optimizer)
export(utils_cluster_silhouette)
export(utils_coerce_time_class)
export(utils_color_breaks)
export(utils_digits)
export(utils_distantia_df_split)
export(utils_drop_geometry)
export(utils_global_scaling_params)
export(utils_is_time)
export(utils_line_color)
export(utils_line_guide)
export(utils_matrix_guide)
export(utils_matrix_plot)
export(utils_new_time)
export(utils_new_time_type)
export(utils_optimize_loess)
export(utils_optimize_spline)
export(utils_prepare_df)
export(utils_prepare_matrix)
export(utils_prepare_matrix_list)
export(utils_prepare_time)
export(utils_prepare_vector_list)
export(utils_prepare_zoo_list)
export(utils_rescale_vector)
export(utils_time_keywords)
export(utils_time_keywords_dictionary)
export(utils_time_keywords_translate)
export(utils_time_units)
export(utils_tsl_pairs)
export(zoo_aggregate)
export(zoo_name_clean)
export(zoo_name_get)
export(zoo_name_set)
export(zoo_permute)
export(zoo_plot)
export(zoo_resample)
export(zoo_simulate)
export(zoo_smooth_exponential)
export(zoo_smooth_window)
export(zoo_time)
export(zoo_to_tsl)
export(zoo_vector_to_matrix)
importFrom(Rcpp,evalCpp)
importFrom(doFuture,"%dofuture%")
useDynLib(distantia)
useDynLib(distantia, .registration = TRUE)
