# Generated by roxyglobals: do not edit by hand

utils::globalVariables(c(
  "distances", # <distance>
  "i", # <distantia>
  "median", # <distantia_boxplot>
  "i", # <distantia_dtw>
  "i", # <distantia_ls>
  "sd", # <distantia_model_frame>
  "sd", # <distantia_stats>
  "i", # <distantia_stats>
  "i", # <distantia_time_delay>
  "i", # <momentum>
  "median", # <momentum_boxplot>
  "i", # <momentum_dtw>
  "i", # <momentum_ls>
  "sd", # <momentum_model_frame>
  "sd", # <momentum_stats>
  "i", # <momentum_stats>
  "i", # <tsl_simulate>
  "i", # <tsl_stats>
  "na.omit", # <tsl_stats>
  "median", # <utils_boxplot_common>
  "distances", # <utils_check_distance_args>
  "i", # <utils_cluster_hclust_optimizer>
  "i", # <utils_cluster_kmeans_optimizer>
  "i", # <zoo_permute>
  "i", # <zoo_resample>
  NULL
))
