% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distantia-package.R
\docType{package}
\name{distantia-package}
\alias{distantia-package}
\title{distantia: A Toolset for Time Series Dissimilarity Analysis}
\description{
Fast C++ implementation of Dynamic Time Warping for time series dissimilarity analysis, with applications in environmental monitoring, sensor data analysis, climate science, signal processing, pattern recognition, and financial data analysis. Built upon the ideas presented in Benito and Birks (2020) \url{doi:10.1111/ecog.04895}, the package provides tools for analyzing time series of varying lengths and structures, including irregular multivariate time series. Key features include individual variable contribution analysis, restricted permutation tests for statistical significance, and imputation of missing data via generalized additive models. Additionally, the package provides comprehensive tools for preparing and managing time series data.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://blasbenito.github.io/distantia/}
  \item Report bugs at \url{https://github.com/BlasBenito/distantia/issues}
}

}
\author{
Blas Benito \href{mailto:blasbenito@gmail.com}{blasbenito@gmail.com}
}
\keyword{internal}
