% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transformations.R
\name{f_clr}
\alias{f_clr}
\title{Data Transformation: Rowwise Centered Log-Ratio}
\usage{
f_clr(x = NULL, ...)
}
\arguments{
\item{x}{(required, zoo object) Zoo time series object to transform.}

\item{...}{(optional, additional arguments) Ignored in this function.}
}
\value{
zoo object
}
\description{
Centers log-transformed proportions by subtracting the geometric mean of the row.
}
\examples{
x <- zoo_simulate(
  cols = 5,
  data_range = c(0, 500)
  )

y <- f_clr(
  x = x
)

if(interactive()){
  zoo_plot(x)
  zoo_plot(y)
}
}
\seealso{
Other tsl_transformation:
\code{\link[=f_binary]{f_binary()}},
\code{\link[=f_detrend_difference]{f_detrend_difference()}},
\code{\link[=f_detrend_linear]{f_detrend_linear()}},
\code{\link[=f_detrend_poly]{f_detrend_poly()}},
\code{\link[=f_hellinger]{f_hellinger()}},
\code{\link[=f_list]{f_list()}},
\code{\link[=f_log]{f_log()}},
\code{\link[=f_percent]{f_percent()}},
\code{\link[=f_proportion]{f_proportion()}},
\code{\link[=f_proportion_sqrt]{f_proportion_sqrt()}},
\code{\link[=f_rescale_global]{f_rescale_global()}},
\code{\link[=f_rescale_local]{f_rescale_local()}},
\code{\link[=f_scale_global]{f_scale_global()}},
\code{\link[=f_scale_local]{f_scale_local()}},
\code{\link[=f_trend_linear]{f_trend_linear()}},
\code{\link[=f_trend_poly]{f_trend_poly()}}
}
\concept{tsl_transformation}
